@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,24 +12,43 @@
 
 #include "btbookshelftreemodel.h"
 
+#include <QDataStream>
+#include <QModelIndexList>
+#include <QPair>
 #include <QtGlobal>
 #include <type_traits>
+#include <utility>
 #include "../../util/btassert.h"
 #include "../../util/btconnect.h"
 #include "../../util/macros.h"
-#include "../config/btconfig.h"
+#include "../config/btconfigcore.h"
+#include "../drivers/btconstmoduleset.h"
+#include "../drivers/btmoduleset.h"
 #include "categoryitem.h"
 #include "indexingitem.h"
 #include "languageitem.h"
 #include "moduleitem.h"
 
-#include <QDebug>
 
 using namespace BookshelfModel;
 
-bool BtBookshelfTreeModel::Grouping::loadFrom(const QString & configKey) {
-    BT_ASSERT(!configKey.isNull());
-    QVariant v = btConfig().qVariantValue(configKey, QVariant());
+BtBookshelfTreeModel::Grouping const BtBookshelfTreeModel::Grouping::NONE;
+BtBookshelfTreeModel::Grouping const BtBookshelfTreeModel::Grouping::CAT =
+        { GROUP_CATEGORY };
+BtBookshelfTreeModel::Grouping const BtBookshelfTreeModel::Grouping::CAT_LANG =
+        { GROUP_CATEGORY, GROUP_LANGUAGE };
+BtBookshelfTreeModel::Grouping const BtBookshelfTreeModel::Grouping::LANG =
+        { GROUP_LANGUAGE };
+BtBookshelfTreeModel::Grouping const BtBookshelfTreeModel::Grouping::LANG_CAT =
+        { GROUP_LANGUAGE, GROUP_CATEGORY };
+BtBookshelfTreeModel::Grouping const BtBookshelfTreeModel::Grouping::DEFAULT =
+        CAT_LANG;
+
+bool BtBookshelfTreeModel::Grouping::loadFrom(BtConfigCore const & config,
+                                              QString const & key)
+{
+    BT_ASSERT(!key.isNull());
+    QVariant const v = config.qVariantValue(key, QVariant());
     if (!v.canConvert<Grouping>())
         return false;
 
@@ -37,56 +56,60 @@ bool BtBookshelfTreeModel::Grouping::loadFrom(const QString & configKey) {
     return true;
 }
 
-void BtBookshelfTreeModel::Grouping::saveTo(const QString & configKey) const {
-    BT_ASSERT(!configKey.isNull());
-    btConfig().setValue(configKey, QVariant::fromValue(*this));
+void BtBookshelfTreeModel::Grouping::saveTo(BtConfigCore & config,
+                                            QString const & key) const
+{
+    BT_ASSERT(!key.isNull());
+    config.setValue(key, QVariant::fromValue(*this));
 }
 
-BtBookshelfTreeModel::BtBookshelfTreeModel(QObject * parent)
+BtBookshelfTreeModel::BtBookshelfTreeModel(QObject * const parent)
     : QAbstractItemModel(parent)
-    , m_sourceModel(nullptr)
-    , m_rootItem(new RootItem)
+    , m_rootItem(std::make_unique<RootItem>())
     , m_defaultChecked(MODULE_HIDDEN)
     , m_checkable(false) {}
 
-BtBookshelfTreeModel::BtBookshelfTreeModel(const QString & configKey,
-                                           QObject * parent)
-       : QAbstractItemModel(parent)
-       , m_sourceModel(nullptr)
-       , m_rootItem(new RootItem)
-       , m_groupingOrder(configKey)
-       , m_defaultChecked(MODULE_HIDDEN)
-       , m_checkable(false) {}
+BtBookshelfTreeModel::BtBookshelfTreeModel(BtConfigCore const & config,
+                                           QString const & configKey,
+                                           QObject * const parent)
+    : QAbstractItemModel(parent)
+    , m_rootItem(std::make_unique<RootItem>())
+    , m_groupingOrder(
+        [](BtConfigCore const & config_, QString const & configKey_){
+            if (Grouping grouping; grouping.loadFrom(config_, configKey_))
+                return grouping;
+            return Grouping::DEFAULT;
+        }(config, configKey))
+    , m_defaultChecked(MODULE_HIDDEN)
+    , m_checkable(false)
+{}
 
-BtBookshelfTreeModel::BtBookshelfTreeModel(const Grouping & grouping,
-                                           QObject * parent)
+BtBookshelfTreeModel::BtBookshelfTreeModel(Grouping const & grouping,
+                                           QObject * const parent)
         : QAbstractItemModel(parent)
-        , m_sourceModel(nullptr)
-        , m_rootItem(new RootItem)
+        , m_rootItem(std::make_unique<RootItem>())
         , m_groupingOrder(grouping)
         , m_defaultChecked(MODULE_HIDDEN)
         , m_checkable(false) {}
 
-BtBookshelfTreeModel::~BtBookshelfTreeModel() {
-    delete m_rootItem;
-}
+BtBookshelfTreeModel::~BtBookshelfTreeModel() = default;
 
-int BtBookshelfTreeModel::rowCount(const QModelIndex & parent) const {
+int BtBookshelfTreeModel::rowCount(QModelIndex const & parent) const {
     return getItem(parent).children().size();
 }
 
-int BtBookshelfTreeModel::columnCount(const QModelIndex & parent) const {
+int BtBookshelfTreeModel::columnCount(QModelIndex const & parent) const {
     Q_UNUSED(parent)
 
     return 1;
 }
 
-bool BtBookshelfTreeModel::hasChildren(const QModelIndex & parent) const {
+bool BtBookshelfTreeModel::hasChildren(QModelIndex const & parent) const {
     return !getItem(parent).children().isEmpty();
 }
 
-QModelIndex BtBookshelfTreeModel::index(int row, int column,
-                                        const QModelIndex & parent) const
+QModelIndex BtBookshelfTreeModel::index(int const row, int const column,
+                                        QModelIndex const & parent) const
 {
     if (!hasIndex(row, column, parent)) return QModelIndex();
 
@@ -98,33 +121,34 @@ QModelIndex BtBookshelfTreeModel::index(int row, int column,
     return createIndex(row, column, childItem);
 }
 
-QModelIndex BtBookshelfTreeModel::parent(const QModelIndex & index) const {
+QModelIndex BtBookshelfTreeModel::parent(QModelIndex const & index) const {
     if (!index.isValid())
         return QModelIndex();
 
-    Item * childItem(static_cast<Item*>(index.internalPointer()));
+    Item const * childItem(static_cast<Item*>(index.internalPointer()));
     BT_ASSERT(childItem);
     Item * parentItem(childItem->parent());
     BT_ASSERT(parentItem);
 
-    if (parentItem == m_rootItem)
+    if (parentItem == m_rootItem.get())
         return QModelIndex();
 
     return createIndex(parentItem->childIndex(), 0, parentItem);
 }
 
-QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
+QVariant
+BtBookshelfTreeModel::data(QModelIndex const & index, int const role) const {
     if (!index.isValid() || index.column() != 0)
         return QVariant();
 
-    const Item * const i = static_cast<Item*>(index.internalPointer());
+    Item const * const i = static_cast<Item*>(index.internalPointer());
     BT_ASSERT(i);
     switch (role) {
 
         case Qt::CheckStateRole:
             if (!m_checkable)
                 break;
-            Q_FALLTHROUGH();
+            [[fallthrough]];
 
         case BtBookshelfTreeModel::CheckStateRole:
             return i->checkState();
@@ -132,7 +156,7 @@ QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
         case BtBookshelfModel::ModulePointerRole:
             /* This case is just an optimization. */
             if (i->type() == Item::ITEM_MODULE) {
-                const ModuleItem & mi = *static_cast<const ModuleItem *>(i);
+                ModuleItem const & mi = *static_cast<ModuleItem const *>(i);
                 return QVariant::fromValue(static_cast<void *>(&mi.moduleInfo()));
             }
             return QVariant::fromValue(nullptr);
@@ -142,7 +166,7 @@ QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
         case BtBookshelfModel::ModuleHiddenRole:
         default:
             if (i->type() == Item::ITEM_MODULE)
-                return data(static_cast<const ModuleItem *>(i)->moduleInfo(), role);
+                return data(static_cast<ModuleItem const *>(i)->moduleInfo(), role);
 
             return i->data(role);
 
@@ -150,14 +174,16 @@ QVariant BtBookshelfTreeModel::data(const QModelIndex & index, int role) const {
     return QVariant();
 }
 
-QVariant BtBookshelfTreeModel::data(CSwordModuleInfo & module, int role) const {
+QVariant
+BtBookshelfTreeModel::data(CSwordModuleInfo & module, int const role) const {
     BT_ASSERT(m_sourceIndexMap.contains(&module));
     return m_sourceModel->data(m_sourceIndexMap.value(&module), role);
 }
 
-bool BtBookshelfTreeModel::setData(const QModelIndex & itemIndex,
-                                   const QVariant & value,
-                                   int role) {
+bool BtBookshelfTreeModel::setData(QModelIndex const & itemIndex,
+                                   QVariant const & value,
+                                   int const role)
+{
     BT_ASSERT(itemIndex.isValid());
     using IP = QPair<Item *, QModelIndex>;
 
@@ -183,19 +209,19 @@ bool BtBookshelfTreeModel::setData(const QModelIndex & itemIndex,
     for (;;) {
         if (item->checkState() != newState) {
             item->setCheckState(newState);
-            emit dataChanged(p.second, p.second);
+            Q_EMIT dataChanged(p.second, p.second);
             if (item->type() == Item::ITEM_MODULE) {
-                ModuleItem & mItem = *static_cast<ModuleItem *>(item);
+                ModuleItem const & mItem = *static_cast<ModuleItem *>(item);
                 CSwordModuleInfo & mInfo = mItem.moduleInfo();
                 if (newState == Qt::Checked) {
                     m_checkedModulesCache.insert(&mInfo);
-                    emit moduleChecked(&mInfo, true);
+                    Q_EMIT moduleChecked(&mInfo, true);
                 } else {
                     m_checkedModulesCache.remove(&mInfo);
-                    emit moduleChecked(&mInfo, false);
+                    Q_EMIT moduleChecked(&mInfo, false);
                 }
             } else {
-                const QList<Item *> & children = item->children();
+                QList<Item *> const & children = item->children();
                 for (int i = 0; i < children.size(); i++)
                     q.append(IP(children.at(i), index(i, 0, p.second)));
             }
@@ -207,12 +233,12 @@ bool BtBookshelfTreeModel::setData(const QModelIndex & itemIndex,
     }
 
     // Recursively change parent check states.
-    resetParentCheckStates(itemIndex.parent());
+    resetParentCheckStates(itemIndex.parent(), false);
 
     return true;
 }
 
-Qt::ItemFlags BtBookshelfTreeModel::flags(const QModelIndex & index) const {
+Qt::ItemFlags BtBookshelfTreeModel::flags(QModelIndex const & index) const {
     if (!index.isValid())
         return Qt::ItemFlags();
 
@@ -221,17 +247,17 @@ Qt::ItemFlags BtBookshelfTreeModel::flags(const QModelIndex & index) const {
     if (m_checkable) {
         f |= Qt::ItemIsUserCheckable;
 
-        const Item & i = *static_cast<Item*>(index.internalPointer());
+        Item const & i = *static_cast<Item*>(index.internalPointer());
         if (i.type() != Item::ITEM_MODULE)
-            f |= Qt::ItemIsTristate;
+            f |= Qt::ItemIsAutoTristate;
     }
 
     return f;
 }
 
-QVariant BtBookshelfTreeModel::headerData(int section,
-                                          Qt::Orientation orientation,
-                                          int role) const
+QVariant BtBookshelfTreeModel::headerData(int const section,
+                                          Qt::Orientation const orientation,
+                                          int const role) const
 {
     if (orientation == Qt::Horizontal)
         return m_sourceModel->headerData(section, orientation, role);
@@ -239,60 +265,63 @@ QVariant BtBookshelfTreeModel::headerData(int section,
     return QVariant();
 }
 
-void BtBookshelfTreeModel::setSourceModel(QAbstractItemModel * sourceModel) {
+void BtBookshelfTreeModel::setSourceModel(
+        std::shared_ptr<QAbstractItemModel> sourceModel)
+{
     if (m_sourceModel == sourceModel)
         return;
 
-    if (m_sourceModel != nullptr) {
-        disconnect(m_sourceModel, &QAbstractItemModel::rowsAboutToBeRemoved,
-                   this,          &BtBookshelfTreeModel::moduleRemoved);
-        disconnect(m_sourceModel, &QAbstractItemModel::rowsInserted,
-                   this,          &BtBookshelfTreeModel::moduleInserted);
-        disconnect(m_sourceModel, &QAbstractItemModel::dataChanged,
-                   this,          &BtBookshelfTreeModel::moduleDataChanged);
-        beginRemoveRows(QModelIndex(), 0, m_rootItem->children().size() - 1);
-        delete m_rootItem;
+    beginResetModel();
+    if (m_sourceModel) {
+        auto & model = *m_sourceModel;
+        disconnect(&model, &QAbstractItemModel::rowsAboutToBeRemoved,
+                   this,   &BtBookshelfTreeModel::moduleRemoved);
+        disconnect(&model, &QAbstractItemModel::rowsInserted,
+                   this,   &BtBookshelfTreeModel::moduleInserted);
+        disconnect(&model, &QAbstractItemModel::dataChanged,
+                   this,   &BtBookshelfTreeModel::moduleDataChanged);
+        m_rootItem = std::make_unique<RootItem>();
         m_modules.clear();
         m_sourceIndexMap.clear();
         m_checkedModulesCache.clear();
-        m_rootItem = new RootItem;
-        endRemoveRows();
     }
 
-    m_sourceModel = sourceModel;
+    m_sourceModel = std::move(sourceModel);
 
-    if (sourceModel != nullptr) {
-        BT_CONNECT(sourceModel, &QAbstractItemModel::rowsAboutToBeRemoved,
-                   this,        &BtBookshelfTreeModel::moduleRemoved);
-        BT_CONNECT(sourceModel, &QAbstractItemModel::rowsInserted,
-                   this,        &BtBookshelfTreeModel::moduleInserted);
-        BT_CONNECT(sourceModel, &QAbstractItemModel::dataChanged,
-                   this,        &BtBookshelfTreeModel::moduleDataChanged);
+    if (m_sourceModel) {
+        auto & model = *m_sourceModel;
+        BT_CONNECT(&model, &QAbstractItemModel::rowsAboutToBeRemoved,
+                   this,   &BtBookshelfTreeModel::moduleRemoved);
+        BT_CONNECT(&model, &QAbstractItemModel::rowsInserted,
+                   this,   &BtBookshelfTreeModel::moduleInserted);
+        BT_CONNECT(&model, &QAbstractItemModel::dataChanged,
+                   this,   &BtBookshelfTreeModel::moduleDataChanged);
 
-        for (int i = 0; i < sourceModel->rowCount(); i++) {
-            const QModelIndex moduleIndex(sourceModel->index(i, 0));
+        for (int i = 0; i < model.rowCount(); i++) {
+            QModelIndex const moduleIndex(model.index(i, 0));
             CSwordModuleInfo & module = *static_cast<CSwordModuleInfo *>(
-                sourceModel->data(moduleIndex,
-                                  BtBookshelfModel::ModulePointerRole).value<void*>());
+                model.data(moduleIndex,
+                           BtBookshelfModel::ModulePointerRole).value<void*>());
 
             bool checked;
             if (m_defaultChecked == MODULE_HIDDEN) {
-                checked = !sourceModel->data(moduleIndex,
-                                             BtBookshelfModel::ModuleHiddenRole).toBool();
+                checked = !model.data(moduleIndex,
+                                      BtBookshelfModel::ModuleHiddenRole).toBool();
             } else if (m_defaultChecked == MODULE_INDEXED) {
-                checked = !sourceModel->data(moduleIndex,
-                                             BtBookshelfModel::ModuleHasIndexRole).toBool();
+                checked = !model.data(moduleIndex,
+                                      BtBookshelfModel::ModuleHasIndexRole).toBool();
             } else {
                 checked = (m_defaultChecked == CHECKED);
             }
             m_sourceIndexMap[&module] = moduleIndex;
-            addModule(module, checked);
+            addModule(module, checked, true);
         }
     }
+    endResetModel();
 }
 
-void BtBookshelfTreeModel::setGroupingOrder(const Grouping & groupingOrder,
-                                            bool emitSignal)
+void BtBookshelfTreeModel::setGroupingOrder(Grouping const & groupingOrder,
+                                            bool const emitSignal)
 {
     if (m_groupingOrder == groupingOrder)
         return;
@@ -303,27 +332,26 @@ void BtBookshelfTreeModel::setGroupingOrder(const Grouping & groupingOrder,
         BtModuleSet const checked(m_checkedModulesCache);
         m_checkedModulesCache.clear();
 
-        beginRemoveRows(QModelIndex(), 0, m_rootItem->children().size() - 1);
-        delete m_rootItem;
+        beginResetModel();
+        m_rootItem = std::make_unique<RootItem>();
         m_modules.clear();
-        m_rootItem = new RootItem;
-        endRemoveRows();
 
         for (int i = 0; i < m_sourceModel->rowCount(); i++) {
-            const QModelIndex sourceIndex(m_sourceModel->index(i, 0));
+            QModelIndex const sourceIndex(m_sourceModel->index(i, 0));
             CSwordModuleInfo & module = *static_cast<CSwordModuleInfo *>(
                 m_sourceModel->data(sourceIndex,
                                     BtBookshelfModel::ModulePointerRole).value<void *>());
             m_sourceIndexMap[&module] = sourceIndex;
-            addModule(module, checked.contains(&module));
+            addModule(module, checked.contains(&module), true);
         }
+        endResetModel();
     }
 
     if (emitSignal)
-        emit groupingOrderChanged(groupingOrder);
+        Q_EMIT groupingOrderChanged(groupingOrder);
 }
 
-void BtBookshelfTreeModel::setCheckable(bool checkable) {
+void BtBookshelfTreeModel::setCheckable(bool const checkable) {
     if (m_checkable == checkable)
         return;
     m_checkable = checkable;
@@ -335,9 +363,7 @@ void BtBookshelfTreeModel::setCheckable(bool checkable) {
 }
 
 void BtBookshelfTreeModel::setCheckedModules(BtConstModuleSet const & modules) {
-    using MIMCI = ModuleItemMap::const_iterator;
-
-    for (MIMCI it = m_modules.constBegin(); it != m_modules.constEnd(); ++it) {
+    for (auto it = m_modules.constBegin(); it != m_modules.constEnd(); ++it) {
         if (modules.contains(it.key())) {
             setData(getIndex(*it.value()), Qt::Checked, Qt::CheckStateRole);
         } else {
@@ -350,97 +376,87 @@ void BtBookshelfTreeModel::resetData() {
     QModelIndexList queue;
     queue.append(QModelIndex());
     do {
-        QModelIndex parent(queue.takeFirst());
-        emit dataChanged(index(0, 0, parent),
+        QModelIndex const parent(queue.takeFirst());
+        Q_EMIT dataChanged(index(0, 0, parent),
                          index(rowCount(parent) - 1, columnCount() - 1, parent));
         for (int i = 0; i < rowCount(parent); i++) {
-            const QModelIndex childIndex(index(i, 0, parent));
+            QModelIndex const childIndex(index(i, 0, parent));
             if (rowCount(childIndex) > 0)
                 queue.append(childIndex);
         }
     } while (!queue.isEmpty());
 }
 
-void BtBookshelfTreeModel::addModule(CSwordModuleInfo & module, bool checked) {
+void BtBookshelfTreeModel::addModule(CSwordModuleInfo & module,
+                                     bool const checked,
+                                     bool const inReset)
+{
     if (m_modules.contains(&module))
         return;
 
-    beginResetModel();
-    Grouping g(m_groupingOrder);
-    addModule(module, QModelIndex(), g, checked);
-
-    /**
-      \bug Calling reset() shouldn't be necessary here, but omitting it will
-           will break things like switching to a grouped layout or installing
-           new modules. As a side effect, all attached views will also reset
-           themselves.
-    */
-
-    endResetModel();
-}
-
-void BtBookshelfTreeModel::addModule(CSwordModuleInfo & module,
-                                     QModelIndex parentIndex,
-                                     Grouping & intermediateGrouping,
-                                     bool checked)
-{
-    if (!intermediateGrouping.empty()) {
-        QModelIndex newIndex;
-        switch (intermediateGrouping.front()) {
-
-            case GROUP_CATEGORY:
-                newIndex = getGroup<CategoryItem>(module, parentIndex);
-                break;
-
-            case GROUP_LANGUAGE:
-                newIndex = getGroup<LanguageItem>(module, parentIndex);
-                break;
-
-            case GROUP_INDEXING:
-                newIndex = getGroup<IndexingItem>(module, parentIndex);
-                break;
-
+    bool beginInsert = !inReset;
+    QModelIndex parentIndex;
+    {
+        auto intermediateGrouping = m_groupingOrder.list();
+        while (!intermediateGrouping.empty()) {
+            switch (intermediateGrouping.takeFirst()) {
+                case GROUP_CATEGORY:
+                    parentIndex = getGroup<CategoryItem>(module,
+                                                         parentIndex,
+                                                         beginInsert);
+                    break;
+                case GROUP_LANGUAGE:
+                    parentIndex = getGroup<LanguageItem>(module,
+                                                         parentIndex,
+                                                         beginInsert);
+                    break;
+                case GROUP_INDEXING:
+                    parentIndex = getGroup<IndexingItem>(module,
+                                                         parentIndex,
+                                                         beginInsert);
+                    break;
+            }
         }
-        intermediateGrouping.pop_front();
-        addModule(module, newIndex, intermediateGrouping, checked);
-    } else {
-        Item & parentItem = getItem(parentIndex);
-        ModuleItem * const newItem = new ModuleItem(module, *this);
-        newItem->setCheckState(checked ? Qt::Checked : Qt::Unchecked);
-        const int newIndex(parentItem.indexFor(newItem));
+    }
 
-        // Actually do the insertion:
+    Item & parentItem = getItem(parentIndex);
+    ModuleItem * const newItem = new ModuleItem(module, *this);
+    newItem->setCheckState(checked ? Qt::Checked : Qt::Unchecked);
+    int const newIndex(parentItem.indexFor(*newItem));
+
+    // Actually do the insertion:
+    if (beginInsert)
         beginInsertRows(parentIndex, newIndex, newIndex);
-        parentItem.insertChild(newIndex, newItem);
-        m_modules.insert(&module, newItem);
-        if (checked) // Add to checked modules cache
-            m_checkedModulesCache.insert(&module);
+    parentItem.insertChild(newIndex, newItem);
+    m_modules.insert(&module, newItem);
+    if (checked) // Add to checked modules cache
+        m_checkedModulesCache.insert(&module);
 
+    if (!inReset)
         endInsertRows();
 
-        // Reset parent item check states, if needed:
-        resetParentCheckStates(parentIndex);
-    }
+    // Reset parent item check states, if needed:
+    resetParentCheckStates(parentIndex, inReset);
 }
 
 void BtBookshelfTreeModel::removeModule(CSwordModuleInfo & module) {
-    using MIMI = ModuleItemMap::iterator;
-    const MIMI it = m_modules.find(&module);
+    auto const it = m_modules.find(&module);
     if (it == m_modules.end())
         return;
 
-    Item * i = it.value();
+    Item const * i = it.value();
 
     // Set i to be the lowest item (including empty groups) to remove:
     BT_ASSERT(i->parent());
-    while (i->parent() != m_rootItem && i->parent()->children().size() <= 1)
+    while (i->parent() != m_rootItem.get()
+           && i->parent()->children().size() <= 1)
         i = i->parent();
     BT_ASSERT(i);
     BT_ASSERT(i->parent());
 
     // Calculate item indexes:
-    const int index = i->childIndex();
-    const QModelIndex parentIndex(getIndex(*i->parent()));
+    int const index = i->childIndex();
+    QModelIndex const parentIndex(getIndex(*i->parent()));
 
     // Actually remove the item:
     beginRemoveRows(parentIndex, index, index);
@@ -450,10 +466,10 @@ void BtBookshelfTreeModel::removeModule(CSwordModuleInfo & module) {
     endRemoveRows();
 
     // Reset parent item check states, if needed:
-    resetParentCheckStates(parentIndex);
+    resetParentCheckStates(parentIndex, false);
 }
 
-Item & BtBookshelfTreeModel::getItem(const QModelIndex & index) const {
+Item & BtBookshelfTreeModel::getItem(QModelIndex const & index) const {
     if (UNLIKELY(!index.isValid()))
         return *m_rootItem;
 
@@ -462,11 +478,11 @@ Item & BtBookshelfTreeModel::getItem(const QModelIndex & index) const {
     return *item;
 }
 
-QModelIndex BtBookshelfTreeModel::getIndex(const BookshelfModel::Item & item) {
-    const BookshelfModel::Item * it = &item;
+QModelIndex BtBookshelfTreeModel::getIndex(BookshelfModel::Item const & item) {
+    BookshelfModel::Item const * it = &item;
     QList<int> indexes;
     for (;;) {
-        const int i = it->childIndex();
+        int const i = it->childIndex();
         if (i < 0)
             break;
         indexes.append(i);
@@ -479,15 +495,17 @@ QModelIndex BtBookshelfTreeModel::getIndex(const BookshelfModel::Item & item) {
     return i;
 }
 
-void BtBookshelfTreeModel::resetParentCheckStates(QModelIndex parentIndex) {
+void BtBookshelfTreeModel::resetParentCheckStates(QModelIndex parentIndex,
+                                                  bool const inReset)
+{
     for ( ; parentIndex.isValid(); parentIndex = parentIndex.parent()) {
         Item & parentItem = *static_cast<Item *>(parentIndex.internalPointer());
 
-        const Qt::CheckState oldState = parentItem.checkState();
+        Qt::CheckState const oldState = parentItem.checkState();
         bool haveCheckedChildren = false;
         bool haveUncheckedChildren = false;
         for (int i = 0; i < parentItem.children().size(); i++) {
-            const Qt::CheckState state = parentItem.children().at(i)->checkState();
+            Qt::CheckState const state = parentItem.children().at(i)->checkState();
             if (state == Qt::PartiallyChecked) {
                 haveCheckedChildren = true;
                 haveUncheckedChildren = true;
@@ -518,12 +536,14 @@ void BtBookshelfTreeModel::resetParentCheckStates(QModelIndex parentIndex) {
             break;
 
         parentItem.setCheckState(newState);
-        emit dataChanged(parentIndex, parentIndex);
+
+        if (!inReset)
+            Q_EMIT dataChanged(parentIndex, parentIndex);
     } // for ( ; parentIndex.isValid(); parentIndex = parentIndex.parent())
 }
 
-void BtBookshelfTreeModel::moduleDataChanged(const QModelIndex & topLeft,
-                                             const QModelIndex & bottomRight)
+void BtBookshelfTreeModel::moduleDataChanged(QModelIndex const & topLeft,
+                                             QModelIndex const & bottomRight)
 {
     BT_ASSERT(!topLeft.parent().isValid());
     BT_ASSERT(!bottomRight.parent().isValid());
@@ -531,14 +551,14 @@ void BtBookshelfTreeModel::moduleDataChanged(const QModelIndex & topLeft,
     BT_ASSERT(bottomRight.column() == 0);
 
     for (int i = topLeft.row(); i <= bottomRight.row(); i++) {
-        const QModelIndex moduleIndex(m_sourceModel->index(i, 0, topLeft.parent()));
-        const QVariant data(m_sourceModel->data(moduleIndex,
+        QModelIndex const moduleIndex(m_sourceModel->index(i, 0, topLeft.parent()));
+        QVariant const data(m_sourceModel->data(moduleIndex,
                                                 BtBookshelfModel::ModulePointerRole));
         CSwordModuleInfo & module = *static_cast<CSwordModuleInfo *>(data.value<void *>());
         QModelIndex itemIndex(getIndex(*m_modules[&module]));
         BT_ASSERT(itemIndex.isValid());
 
-        emit dataChanged(itemIndex, itemIndex);
+        Q_EMIT dataChanged(itemIndex, itemIndex);
 
         /*
           Also emit signals for parent items because the change might alter them
@@ -546,20 +566,20 @@ void BtBookshelfTreeModel::moduleDataChanged(const QModelIndex & topLeft,
         */
         do {
             itemIndex = itemIndex.parent();
-            emit dataChanged(itemIndex, itemIndex);
+            Q_EMIT dataChanged(itemIndex, itemIndex);
         } while (itemIndex.isValid());
     }
 }
 
-void BtBookshelfTreeModel::moduleInserted(const QModelIndex & parent,
-                                          int start,
-                                          int end)
+void BtBookshelfTreeModel::moduleInserted(QModelIndex const & parent,
+                                          int const start,
+                                          int const end)
 {
     BT_ASSERT(start <= end);
 
     for (int i = start; i <= end; i++) {
-        const QModelIndex moduleIndex(m_sourceModel->index(i, 0, parent));
-        const QVariant data(m_sourceModel->data(moduleIndex,
+        QModelIndex const moduleIndex(m_sourceModel->index(i, 0, parent));
+        QVariant const data(m_sourceModel->data(moduleIndex,
                                                 BtBookshelfModel::ModulePointerRole));
         CSwordModuleInfo & module = *static_cast<CSwordModuleInfo *>(data.value<void *>());
 
@@ -575,19 +595,19 @@ void BtBookshelfTreeModel::moduleInserted(const QModelIndex & parent,
             checked = (m_defaultChecked == CHECKED);
         }
         m_sourceIndexMap[&module] = moduleIndex;
-        addModule(module, checked);
+        addModule(module, checked, false);
     }
 }
 
-void BtBookshelfTreeModel::moduleRemoved(const QModelIndex & parent,
-                                         int start,
-                                         int end)
+void BtBookshelfTreeModel::moduleRemoved(QModelIndex const & parent,
+                                         int const start,
+                                         int const end)
 {
     BT_ASSERT(start <= end);
 
     for (int i = start; i <= end; i++) {
-        const QModelIndex moduleIndex(m_sourceModel->index(i, 0, parent));
-        const QVariant data(m_sourceModel->data(moduleIndex,
+        QModelIndex const moduleIndex(m_sourceModel->index(i, 0, parent));
+        QVariant const data(m_sourceModel->data(moduleIndex,
                                                 BtBookshelfModel::ModulePointerRole));
         CSwordModuleInfo & module = *static_cast<CSwordModuleInfo *>(data.value<void*>());
         removeModule(module);
@@ -596,24 +616,25 @@ void BtBookshelfTreeModel::moduleRemoved(const QModelIndex & parent,
 }
 
 QDataStream & operator <<(QDataStream & os,
-                          const BtBookshelfTreeModel::Grouping & o)
+                          BtBookshelfTreeModel::Grouping const & o)
 {
-    os << o.size();
-    Q_FOREACH(BtBookshelfTreeModel::Group const g, o)
-        os << static_cast<std::underlying_type<decltype(g)>::type>(g);
+    os << o.list().size();
+    for (auto const g : o.list())
+        os << static_cast<std::underlying_type_t<decltype(g)>>(g);
     return os;
 }
 
 QDataStream & operator >>(QDataStream & is,
                           BtBookshelfTreeModel::Grouping & o)
 {
-    int s;
+    decltype(o.list().size()) s;
     is >> s;
-    o.clear();
-    for (int i = 0; i < s; i++) {
-        int g;
+    decltype(o.m_list) newList;
+    for (decltype(s) i = 0; i < s; i++) {
+        std::underlying_type_t<BtBookshelfTreeModel::Group> g;
         is >> g;
-        o.append(static_cast<BtBookshelfTreeModel::Group>(g));
+        newList.append(static_cast<BtBookshelfTreeModel::Group>(g));
     }
+    o.m_list = std::move(newList);
     return is;
 }
