@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,12 +12,14 @@
 
 #include "languageitem.h"
 
+#include <QIcon>
 #include "../../util/cresmgr.h"
+#include "../language.h"
 
 
 namespace BookshelfModel {
 
-QVariant LanguageItem::data(int role) const {
+QVariant LanguageItem::data(int const role) const {
     switch (role) {
 
         case Qt::DisplayRole:
