@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,12 +12,19 @@
 
 #include "btinstallmgr.h"
 
+#include <QByteArray>
+#include <QtGlobal>
 #include <type_traits>
 #include <utility>
 #include "../util/btassert.h"
 #include "btinstallbackend.h"
 
 
+// Sword includes:
+#include <defs.h>
+#include <installmgr.h>
+
+
 namespace {
 
 template <typename T>
@@ -37,25 +44,20 @@ inline int calculateIntPercentage(T done, T total) {
     // Special care (see warning in BtInstallMgr::statusUpdate()).
     if (done > total)
         done = total;
-    if (total == 0)
+    if (total <= 0.0)
         return 100;
 
     return normalizeCompletionPercentage<int>((done / total) * 100);
 }
 
-template <typename ... Ts> struct MakeVoid { using type = void; };
-template <typename ... Ts> using VoidT = typename MakeVoid<Ts...>::type;
-
 template <typename T, class = void>
-struct TimeoutDisabler { void operator()(T &) const noexcept {} };
+struct HasSetTimeoutMillis : std::false_type {};
 
 template <typename T>
-struct TimeoutDisabler<T,
-        VoidT<decltype(std::declval<T &>().setTimeoutMillis(0))>>
-{
-    void operator()(T & obj) const noexcept
-    { obj.setTimeoutMillis(0); }
-};
+struct HasSetTimeoutMillis<T,
+        std::void_t<decltype(std::declval<T &>().setTimeoutMillis(0))>>
+    : std::true_type
+{};
 
 } // anonymous namespace
 
@@ -67,9 +69,10 @@ BtInstallMgr::BtInstallMgr(QObject * parent)
         , m_totalBytes(1)
         , m_completedBytes(0)
         , m_firstCallOfPreStatus(true)
-{ // Use this class also as status reporter:
-    this->setFTPPassive(true);
-    TimeoutDisabler<BtInstallMgr>()(*this);
+{
+    setFTPPassive(true);
+    if constexpr (HasSetTimeoutMillis<BtInstallMgr>::value)
+        setTimeoutMillis(0);
 }
 
 BtInstallMgr::~BtInstallMgr() {
@@ -101,7 +104,7 @@ void BtInstallMgr::statusUpdate(double dltotal, double dlnow) {
     const int filePercent  = calculateIntPercentage(dlnow, dltotal);
 
     //qApp->processEvents();
-    emit percentCompleted(totalPercent, filePercent);
+    Q_EMIT percentCompleted(totalPercent, filePercent);
 }
 
 
@@ -109,11 +112,11 @@ void BtInstallMgr::preStatus(long totalBytes,
                              long completedBytes,
                              const char * message)
 {
-    Q_UNUSED(message);
+    Q_UNUSED(message)
     BT_ASSERT(completedBytes <= totalBytes);
     if (m_firstCallOfPreStatus) {
         m_firstCallOfPreStatus = false;
-        emit downloadStarted();
+        Q_EMIT downloadStarted();
     }
     m_completedBytes = completedBytes;
     m_totalBytes = totalBytes;
