@@ -2,22 +2,27 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTINSTALLMGR_H
-#define BTINSTALLMGR_H
+#pragma once
 
 #include <QObject>
 
+#include <QString>
+
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wextra-semi"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
 #include <installmgr.h>
 #include <remotetrans.h>
+#pragma GCC diagnostic pop
 
 
 /**
@@ -26,19 +31,19 @@
 class BtInstallMgr
         : public QObject
         , public sword::InstallMgr
-        , public sword::StatusReporter
+        , private sword::StatusReporter
 {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
     BtInstallMgr(QObject * parent = nullptr);
     ~BtInstallMgr() override;
 
     bool isUserDisclaimerConfirmed() const override;
 
-signals:
+Q_SIGNALS:
 
     /**
       Download status. Percent of total and file.
@@ -48,7 +53,7 @@ signals:
 
     void downloadStarted();
 
-protected: /* Methods: */
+protected: // methods:
 
     /** \note Reimplementation of sword::StatusReporter::statusUpdate(). */
     void statusUpdate(double dltotal, double dlnow) override;
@@ -64,12 +69,10 @@ protected: /* Methods: */
                    long completedBytes,
                    const char * message) override;
 
-private: /* Fields: */
+private: // fields:
 
     long m_totalBytes;
     long m_completedBytes;
     bool m_firstCallOfPreStatus;
 
 };
-
-#endif /* BTINSTALLMGR_H */
