@@ -2,25 +2,28 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef FILTERS_PLAINTOHTML_H
-#define FILTERS_PLAINTOHTML_H
+#pragma once
 
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
 #include <swfilter.h>
+#pragma GCC diagnostic pop
 
 
 namespace sword {
-    class SWKey;
-    class SWModule;
-}
+class SWBuf;
+class SWKey;
+class SWModule;
+} // namespace sword
 
 namespace Filters {
 
@@ -29,7 +32,7 @@ namespace Filters {
 */
 class PlainToHtml: public sword::SWFilter {
 
-    protected: /* Methods: */
+    protected: // methods:
 
         /** Reimplemented from sword::SWFilter. */
         char processText(sword::SWBuf &buf,
@@ -39,5 +42,3 @@ class PlainToHtml: public sword::SWFilter {
 };
 
 } // namespace Filters
-
-#endif
