@@ -2,20 +2,32 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef FILTERS_TEITOHTML_H
-#define FILTERS_TEITOHTML_H
+#pragma once
 
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wextra-semi"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wsuggest-destructor-override"
+#endif
 #include <teihtmlhref.h>
 #include <swbuf.h>
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+#pragma GCC diagnostic pop
+
 
 namespace Filters {
 
@@ -23,14 +35,14 @@ namespace Filters {
   \brief TEI to HTML conversion filter.
 */
 class TeiToHtml: public sword::TEIHTMLHREF {
-    public: /* Methods: */
+    public: // methods:
         TeiToHtml();
 
         bool handleToken(sword::SWBuf &buf,
                          const char *token,
                          sword::BasicFilterUserData *userData) override;
 
-    private: /* Methods: */
+    private: // methods:
         void renderReference(const char *osisRef, sword::SWBuf &buf,
                              sword::BasicFilterUserData *myUserData);
         void renderTargetReference(const char *osisRef, sword::SWBuf &buf,
@@ -38,5 +50,3 @@ class TeiToHtml: public sword::TEIHTMLHREF {
 };
 
 } // namespace Filters
-
-#endif
