@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,36 +12,45 @@
 
 #include "cswordldkey.h"
 
-#include <QTextCodec>
+#include <QByteArray>
 #include "../../util/btassert.h"
-#include "../drivers/cswordlexiconmoduleinfo.h"
+#include "../../util/cp1252.h"
+#include "../drivers/cswordmoduleinfo.h"
 
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wextra-semi"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wsuggest-destructor-override"
+#endif
+#include <swkey.h>
 #include <swmodule.h>
-#include <swld.h>
-#include <utilstr.h>
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+#pragma GCC diagnostic pop
 
 
-CSwordLDKey::CSwordLDKey(const CSwordModuleInfo *module) {
-    if ((m_module = dynamic_cast<const CSwordLexiconModuleInfo*>(module))) {
-        //    *(m_module->module()) = TOP;
-    }
-
-    SWKey::operator= (" ");
-}
+CSwordLDKey::CSwordLDKey(CSwordModuleInfo const * module)
+    : CSwordKey(module)
+{ m_key = " "; }
 
 /** No descriptions */
 CSwordLDKey::CSwordLDKey(CSwordLDKey const & k)
     : CSwordKey(k)
-    , SWKey(k.getText())
+    , m_key(k.m_key.getText())
 {}
 
 /** No descriptions */
-CSwordLDKey::CSwordLDKey(const SWKey *k, const CSwordModuleInfo *module)
-    : CSwordKey(module), SWKey(*k)
-{
-    // Intentionally empty
-}
+CSwordLDKey::CSwordLDKey(const sword::SWKey *k, const CSwordModuleInfo *module)
+    : CSwordKey(module)
+    , m_key(*k)
+{}
+
+sword::SWKey const & CSwordLDKey::asSwordKey() const noexcept { return m_key; }
 
 /** Clones this object by copying the members. */
 CSwordLDKey* CSwordLDKey::copy() const {
@@ -64,14 +73,14 @@ QString CSwordLDKey::key() const {
     BT_ASSERT(m_module);
 
     if (m_module->isUnicode()) {
-        return QString::fromUtf8(getText());
+        return QString::fromUtf8(m_key.getText());
     } else {
-        return cp1252Codec()->toUnicode(getText());
+        return util::cp1252::toUnicode(m_key.getText());
     }
 }
 
 const char * CSwordLDKey::rawKey() const {
-    return getText();
+    return m_key.getText();
 }
 
 bool CSwordLDKey::setKey(const QString &newKey) {
@@ -81,7 +90,7 @@ bool CSwordLDKey::setKey(const QString &newKey) {
         return setKey(newKey.toUtf8().constData());
     }
     else {
-        return setKey(cp1252Codec()->fromUnicode(newKey).constData());
+        return setKey(util::cp1252::fromUnicode(newKey).constData());
     }
 }
 
@@ -91,18 +100,18 @@ bool CSwordLDKey::setKey(const char *newKey) {
     BT_ASSERT(newKey);
 
     if (newKey) {
-        SWKey::operator = (newKey); //set the key
-        m_module->module().setKey(this);
+        m_key = newKey; //set the key
+        m_module->swordModule().setKey(&m_key);
         m_module->snap();
     }
 
-    return !popError();
+    return !m_key.popError();
 }
 
 /** Uses the parameter to returns the next entry afer this key. */
 CSwordLDKey* CSwordLDKey::NextEntry() {
-    auto & m = m_module->module();
-    m.setKey(this); // use this key as base for the next one!
+    auto & m = m_module->swordModule();
+    m.setKey(&m_key); // use this key as base for the next one!
     //   m.getKey()->setText( (const char*)key().utf8() );
 
     m.setSkipConsecutiveLinks(true);
@@ -110,22 +119,22 @@ CSwordLDKey* CSwordLDKey::NextEntry() {
     m.setSkipConsecutiveLinks(false);
 
     setKey(m.getKeyText());
-    setText(m.getKeyText());
+    m_key.setText(m.getKeyText());
 
     return this;
 }
 
 /** Uses the parameter to returns the next entry afer this key. */
 CSwordLDKey* CSwordLDKey::PreviousEntry() {
-    auto & m = m_module->module();
-    m.setKey(this); // use this key as base for the next one!
+    auto & m = m_module->swordModule();
+    m.setKey(&m_key); // use this key as base for the next one!
     //   m.getKey()->setText( (const char*)key().utf8() );
 
     m.setSkipConsecutiveLinks(true);
     m--;
     m.setSkipConsecutiveLinks(false);
 
-    setText(m.getKeyText());
+    m_key.setText(m.getKeyText());
 
     return this;
 }
