@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -17,9 +17,16 @@
 #include <QLabel>
 #include <QProgressBar>
 #include <QPushButton>
+#include <QSizePolicy>
+#include <QSpacerItem>
+#include <QStringLiteral>
+#include <Qt>
 #include <QVBoxLayout>
-#include "../../backend/btinstallbackend.h"
+#include <QWizardPage>
 #include "../../backend/btinstallthread.h"
+#include "../../backend/drivers/btmoduleset.h"
+#include "../../backend/drivers/cswordmoduleinfo.h"
+#include "../../backend/managers/cswordbackend.h"
 #include "../../util/btconnect.h"
 #include "btbookshelfwizard.h"
 #include "btbookshelfwizardenums.h"
@@ -36,7 +43,6 @@ BtBookshelfInstallFinalPage::BtBookshelfInstallFinalPage(QWidget * parent)
 {
     // Setup UI:
     m_verticalLayout = new QVBoxLayout(this);
-    m_verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
 
     m_verticalLayout->addItem(new QSpacerItem(20,
                                               40,
@@ -54,7 +60,6 @@ BtBookshelfInstallFinalPage::BtBookshelfInstallFinalPage(QWidget * parent)
     m_verticalLayout->addWidget(m_msgLabel2);
 
     m_progressBar = new QProgressBar(this);
-    m_progressBar->setObjectName("progressBar");
     m_progressBar->setMinimum(0);
     m_progressBar->setMaximum(100);
     m_verticalLayout->addWidget(m_progressBar,Qt::AlignCenter);
@@ -179,17 +184,17 @@ void BtBookshelfInstallFinalPage::slotThreadFinished() {
     m_progressBar->setValue(100);
     m_stopButton->setEnabled(false);
     if (m_installFailed) {
-        m_msgLabel->setText(tr("Some of the selected works were not "
-                               "installed."));
+        m_msgLabel->setText(
+                    tr("Some of the selected works were not installed."));
         m_msgLabel->setStyleSheet("QLabel{color:red}");
     } else {
         m_msgLabel->setText(tr("The selected works have been installed."));
     }
     m_msgLabel2->setText("");
 
-    CSwordBackend::instance()->reloadModules(CSwordBackend::AddedModules);
+    CSwordBackend::instance().reloadModules();
 
     m_installCompleted = true;
-    emit QWizardPage::completeChanged();
+    Q_EMIT QWizardPage::completeChanged();
     btWizard().downloadFinished();
 }
