@@ -2,40 +2,40 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFINSTALLFINALPAGE
-#define BTBOOKSHELFINSTALLFINALPAGE
+#pragma once
 
 #include "btbookshelfwizardpage.h"
 
 #include <QList>
+#include <QObject>
+#include <QString>
 #include "../../backend/drivers/btmoduleset.h"
 
 
-class BtBookshelfWizard;
 class BtInstallThread;
+class CSwordModuleInfo;
 class QLabel;
 class QProgressBar;
 class QPushButton;
-class QSwordModuleInfo;
 class QVBoxLayout;
+class QWidget;
 
 class BtBookshelfInstallFinalPage final: public BtBookshelfWizardPage {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
-    BtBookshelfInstallFinalPage(QWidget * parent = 0);
-    inline ~BtBookshelfInstallFinalPage() noexcept final override
-    { destroyThread(); }
+    BtBookshelfInstallFinalPage(QWidget * parent = nullptr);
+    ~BtBookshelfInstallFinalPage() noexcept final override { destroyThread(); }
 
     void destroyThread() noexcept;
 
@@ -44,21 +44,21 @@ public: /* Methods: */
     int nextId() const final override;
     BtModuleSet selectedWorks() const;
 
-public slots:
+public Q_SLOTS:
     void slotStopInstall();
 
-private slots:
+private Q_SLOTS:
 
     void slotInstallStarted(int moduleIndex);
     void slotOneItemCompleted(int moduleIndex, bool status);
     void slotStatusUpdated(int moduleIndex, int status);
     void slotThreadFinished();
 
-private: /* Methods: */
+private: // methods:
 
     void retranslateUi();
 
-private: /* Fields: */
+private: // fields:
 
     QLabel * m_msgLabel;
     QLabel * m_msgLabel2;
@@ -74,5 +74,3 @@ private: /* Fields: */
     int m_lastStatus = -1;
 
 }; /* class BtBookshelfInstallFinalPage */
-
-#endif
