@@ -2,34 +2,35 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFLANGUAGESPAGE
-#define BTBOOKSHELFLANGUAGESPAGE
+#pragma once
 
 #include "btbookshelfwizardpage.h"
 
+#include <QObject>
+#include <QString>
 #include <QStringList>
 
 
-class BtBookshelfWizard;
-class BtListModel;
 class QListView;
+class QStandardItemModel;
 class QVBoxLayout;
+class QWidget;
 
 class BtBookshelfLanguagesPage final: public BtBookshelfWizardPage {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
-    BtBookshelfLanguagesPage(QWidget * parent = 0);
+    BtBookshelfLanguagesPage(QWidget * parent = nullptr);
 
     void initializeLanguages();
     void initializePage() final override;
@@ -38,21 +39,19 @@ public: /* Methods: */
     QStringList selectedLanguages() const;
     bool skipPage() const noexcept;
 
-private slots:
+private Q_SLOTS:
 
     void slotDataChanged();
 
-private: /* Methods: */
+private: // methods:
 
     void retranslateUi();
 
-private: /* Fields: */
+private: // fields:
 
     bool m_firstTimeInit = true;
     QListView * m_languagesListView;
     QVBoxLayout * m_verticalLayout;
-    BtListModel * m_model;
+    QStandardItemModel * m_model;
 
 }; /* class BtBookshelfLanguagesPage */
-
-#endif
