@@ -2,59 +2,56 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFSOURCESPAGE
-#define BTBOOKSHELFSOURCESPAGE
+#pragma once
 
 #include "btbookshelfwizardpage.h"
 
+#include <QObject>
+#include <QString>
 #include <QStringList>
 
 
-class BtInstallMgr;
-class BtListModel;
-class QPushButton;
+class QStandardItemModel;
 class QTableView;
 class QVBoxLayout;
+class QWidget;
 
 class BtBookshelfSourcesPage final: public BtBookshelfWizardPage {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
-    BtBookshelfSourcesPage(QWidget * parent = 0);
+    BtBookshelfSourcesPage(QWidget * parent = nullptr);
 
     bool isComplete() const final override;
     void initializePage() final override;
     int nextId() const final override;
     QStringList selectedSources() const;
 
-private slots:
+private Q_SLOTS:
 
     void slotButtonClicked(int row);
 
-private: /* Methods: */
+private: // methods:
 
     void retranslateUi();
     void selectSourcesInModel(QStringList const & sources);
     void updateSourcesModel();
 
-private: /* Fields: */
+private: // fields:
 
     bool m_firstTimeInit = true;
     QTableView * m_sourcesTableView;
     QVBoxLayout * m_verticalLayout;
-    BtListModel * m_model;
-    BtInstallMgr * m_currentInstallMgr;
+    QStandardItemModel * m_model;
 
 }; /* class BtBookshelfSourcesPage */
-
-#endif
