@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -15,10 +15,14 @@
 #include <QAbstractButton>
 #include <QApplication>
 #include <QByteArray>
+#include <QDialog>
 #include <QKeyEvent>
 #include <QMessageBox>
 #include <QPushButton>
+#include <QRect>
 #include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/btmoduleset.h"
+#include "../../util/btassert.h"
 #include "btbookshelfinstallfinalpage.h"
 #include "btbookshelflanguagespage.h"
 #include "btbookshelfremovefinalpage.h"
@@ -30,9 +34,9 @@
 
 
 namespace {
-QString const GeometryKey = "GUI/BookshelfWizard/geometry";
-QString const SourcesKey = "GUI/BookshelfWizard/sources";
-QString const LanguagesKey = "GUI/BookshelfWizard/languages";
+auto const GeometryKey = QStringLiteral("GUI/BookshelfWizard/geometry");
+auto const SourcesKey = QStringLiteral("GUI/BookshelfWizard/sources");
+auto const LanguagesKey = QStringLiteral("GUI/BookshelfWizard/languages");
 bool autoSourcesUpdate = true;
 } // anonymous namespace
 
