@@ -2,16 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFWIZARDENUM_H
-#define BTBOOKSHELFWIZARDENUM_H
+#pragma once
 
 enum WizardPage: int {
     taskPage,
@@ -30,5 +29,3 @@ enum WizardTaskType {
     updateWorks,
     removeWorks
 };
-
-#endif
