@@ -2,25 +2,30 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTINSTALLPAGEMODEL_H
-#define BTINSTALLPAGEMODEL_H
+#pragma once
 
 #include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
 
+#include <QModelIndex>
+#include <QObject>
+#include <QString>
+#include <QVariant>
+#include <Qt>
+
 
 class BtInstallPageModel: public BtBookshelfTreeModel {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
     BtInstallPageModel(Grouping const & grouping,
                        QObject * const parent = nullptr);
@@ -34,5 +39,3 @@ public: /* Methods: */
                         int role = Qt::DisplayRole) const final override;
 
 }; /* class BtInstallPageModel */
-
-#endif /* BTINSTALLPAGEMODEL_H */
