@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,15 +13,27 @@
 #include "btaboutdialog.h"
 
 #include <QApplication>
+#include <QColor>
+#include <QDebug>
 #include <QDesktopServices>
 #include <QDialogButtonBox>
+#include <QDir>
+#include <QFile>
+#include <QFont>
 #include <QFontMetrics>
+#include <QHBoxLayout>
+#include <QIODevice>
 #include <QLabel>
+#include <QPalette>
+#include <QPlainTextEdit>
 #include <QTabWidget>
 #include <QTextBrowser>
 #include <QTextStream>
+#include <QtGlobal>
 #include <QUrl>
 #include <QVBoxLayout>
+#include <QWidget>
+#include <utility>
 #include "../util/btconnect.h"
 #include "../util/bticons.h"
 #include "../util/directory.h"
@@ -53,6 +65,41 @@
     (c) += (r2);\
     (c) += ")</li>"
 
+class BtAboutDialog::LicenseTab final : public QWidget {
+
+public: // Methods:
+
+    LicenseTab(QWidget * parent)
+        : QWidget(parent)
+        , m_label(new QLabel(this))
+        , m_licenseBrowser(new QPlainTextEdit(this))
+    {
+        auto * const mainLayout = new QVBoxLayout(this);
+
+        m_label->setWordWrap(true);
+        mainLayout->addWidget(m_label);
+
+        m_licenseBrowser->setReadOnly(true);
+        { // Set monospace font:
+            QFont licenseFont(QStringLiteral("BibleTime nonexistant font"));
+            licenseFont.setStyleHint(QFont::Monospace);
+            m_licenseBrowser->setFont(std::move(licenseFont));
+        }
+        mainLayout->addWidget(m_licenseBrowser);
+    }
+
+    void setLabelText(QString const & text) { m_label->setText(text); }
+
+    void setLicense(QString const & license)
+    { m_licenseBrowser->setPlainText(license); }
+
+private: // Fields
+
+    QLabel * const m_label;
+    QPlainTextEdit * const m_licenseBrowser;
+
+}; // LicenseTab
+
 BtAboutDialog::BtAboutDialog(QWidget *parent, Qt::WindowFlags wflags)
         : QDialog(parent, wflags)
 {
@@ -78,23 +125,51 @@ BtAboutDialog::BtAboutDialog(QWidget *parent, Qt::WindowFlags wflags)
     m_tabWidget = new QTabWidget(this);
     mainLayout->addWidget(m_tabWidget);
 
-    initTab(m_bibletimeTab);
-    initTab(m_contributorsTab);
-    initTab(m_swordTab);
-    initTab(m_qtTab);
-    initTab(m_licenceTab);
+    auto const addTab = [this]{
+        auto * const tab = new QTextBrowser(this);
+        tab->setOpenLinks(false);
+        m_tabWidget->addTab(tab, "");
+        BT_CONNECT(tab, &QTextBrowser::anchorClicked,
+                   [](QUrl const & url) {
+                       if (url.scheme() == "qt") {
+                           qApp->aboutQt();
+                       } else {
+                           QDesktopServices::openUrl(url);
+                       }
+                   });
+        return tab;
+    };
+
+    m_bibletimeTab = addTab();
+    m_contributorsTab = addTab();
+    m_swordTab = addTab();
+    m_qtTab = addTab();
+
+    {
+        auto const & licensePath = util::directory::getLicensePath();
+        QFile licenseFile(licensePath);
+        if (licenseFile.open(QFile::ReadOnly)) {
+            m_licenseTab = new LicenseTab(this);
+            m_licenseTab->setLicense(QTextStream(&licenseFile).readAll());
+            m_tabWidget->addTab(m_licenseTab, "");
+            licenseFile.close();
+        } else {
+            qWarning() << "Failed to read license from" << licensePath;
+        }
+    }
 
     m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, Qt::Horizontal, this);
     mainLayout->addWidget(m_buttonBox);
     setLayout(mainLayout);
 
-    BT_CONNECT(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    BT_CONNECT(m_buttonBox, &QDialogButtonBox::rejected,
+               this, &BtAboutDialog::reject);
 
     retranslateUi();
 }
 
 void BtAboutDialog::resizeEvent(QResizeEvent* event) {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
     QString version = "BibleTime " BT_VERSION;
     QFontMetrics fm(m_versionLabel->font());
     int w = width()  - m_iconLabel->width() - 80;
@@ -102,17 +177,6 @@ void BtAboutDialog::resizeEvent(QResizeEvent* event) {
     m_versionLabel->setText(shortVersion);
 }
 
-
-void BtAboutDialog::initTab(QTextBrowser *&tab) {
-    tab = new QTextBrowser(this);
-    tab->setOpenExternalLinks(true);
-    QFont font = tab->font();
-    font.setPointSize(font.pointSize()+2);
-    tab->setFont(font);
-    m_tabWidget->addTab(tab, "");
-    BT_CONNECT(tab, SIGNAL(anchorClicked(const QUrl&)), this, SLOT(linkClicked(const QUrl&)));
-}
-
 void BtAboutDialog::retranslateUi() {
     setWindowTitle(tr("About BibleTime"));
 
@@ -131,10 +195,10 @@ void BtAboutDialog::retranslateBtTab() {
     QString content("<p>");
     content += tr("BibleTime is an easy to use but powerful Bible study tool.");
     content += "</p><p>";
-    content += tr("(c)1999-2020, The BibleTime Team");
-    content += "</p><p>" MAKE_LINK_STATIC("http://www.bibletime.info", "www.bibletime.info")
+    content += tr("(c)1999-2025, The BibleTime Team");
+    content += "</p><p>" MAKE_LINK_STATIC("https://bibletime.info", "bibletime.info")
                "</p>";
-    m_bibletimeTab->setText(MAKE_HTML(m_bibletimeTab, content));
+    m_bibletimeTab->setHtml(MAKE_HTML(m_bibletimeTab, content));
 }
 
 void BtAboutDialog::retranslateContributorsTab() {
@@ -231,7 +295,7 @@ void BtAboutDialog::retranslateContributorsTab() {
                           "https://github.com/bibletime/bibletime/issues"));
     content += "</p>";
 
-    m_contributorsTab->setText(MAKE_HTML(m_contributorsTab, content));
+    m_contributorsTab->setHtml(MAKE_HTML(m_contributorsTab, content));
 }
 
 
@@ -252,7 +316,7 @@ void BtAboutDialog::retranslateSwordTab() {
     content += MAKE_LINK_STATIC("http://www.crosswire.org/sword/",
                                 "www.crosswire.org/sword") "</p>";
 
-    m_swordTab->setText(MAKE_HTML(m_swordTab, content));
+    m_swordTab->setHtml(MAKE_HTML(m_swordTab, content));
 }
 
 void BtAboutDialog::retranslateQtTab() {
@@ -266,39 +330,24 @@ void BtAboutDialog::retranslateQtTab() {
     content += tr("Qt is a cross-platform application and UI framework, created with C++ "
                   "language. It has been released under the LGPL license.");
 
-    // See BtUrlHandler
     content += " " MAKE_LINK(content, "qt://about", tr("More info...")) "</p>";
 
-    m_qtTab->setText(MAKE_HTML(m_qtTab, content));
+    m_qtTab->setHtml(MAKE_HTML(m_qtTab, content));
 }
 
 void BtAboutDialog::retranslateLicenceTab() {
-    m_tabWidget->setTabText(4, tr("&License"));
+    if (!m_licenseTab)
+        return;
 
-    QFile licFile(util::directory::getLicenseDir().path() + "/license.html");
-    if (licFile.open(QFile::ReadOnly)) {
+    m_tabWidget->setTabText(m_tabWidget->indexOf(m_licenseTab), tr("&License"));
 
-        QString text("<p>");
-        text += tr("BibleTime is released under the GPL license. You can download and use "
-                   "the program for personal, private, public or "
-                   "commercial purposes without restrictions, but can give away or "
-                   "distribute the program only if you also distribute the corresponding source "
-                   "code.");
-        text += "</p><p>";
-        text += tr("The complete legally binding license is below.");
-        text += "</p><hr/>";
-
-        QString content(QTextStream(&licFile).readAll().replace("<!-- TR TEXT -->", text));
-        content.replace("<!-- HEADER -->", MAKE_STYLE(m_licenceTab), Qt::CaseInsensitive);
-        m_licenceTab->setText(content);
-        licFile.close();
-    }
-}
-
-void BtAboutDialog::linkClicked(const QUrl &url) {
-    if (url.host() == "qt") {
-            qApp->aboutQt();
-    } else {
-        QDesktopServices::openUrl(url);
-    }
+    m_licenseTab->setLabelText(
+                QStringLiteral("<p>%1</p><p>%2</p>")
+                .arg(tr("BibleTime is released under the GPL license. You "
+                        "can download and use the program for personal, "
+                        "private, public or commercial purposes without "
+                        "restrictions, but can give away or distribute the "
+                        "program only if you also distribute the "
+                        "corresponding source code."),
+                     tr("The complete legally binding license is below.")));
 }
