@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,7 +14,6 @@
 #include <QDialogButtonBox>
 #include <QTextEdit>
 #include <QVBoxLayout>
-#include <QWidget>
 #include "../backend/drivers/cswordmoduleinfo.h"
 #include "../util/btconnect.h"
 #include "btaboutmoduledialog.h"
@@ -36,12 +35,14 @@ BTAboutModuleDialog::BTAboutModuleDialog(const CSwordModuleInfo *moduleInfo,
     vboxLayout->addWidget(m_textEdit);
 
     m_buttons = new QDialogButtonBox(QDialogButtonBox::Close, Qt::Horizontal, this);
-    BT_CONNECT(m_buttons, SIGNAL(rejected()), this, SLOT(reject()));
+    BT_CONNECT(m_buttons, &QDialogButtonBox::rejected,
+               this, &BTAboutModuleDialog::reject);
     vboxLayout->addWidget(m_buttons);
 
     retranslateUi();
 
-    BT_CONNECT(moduleInfo, SIGNAL(destroyed()), this, SLOT(close()));
+    BT_CONNECT(moduleInfo, &QObject::destroyed,
+               this, &BTAboutModuleDialog::close);
 }
 
 void BTAboutModuleDialog::retranslateUi() {
