@@ -2,23 +2,27 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTABOUTMODULEDIALOG_H
-#define BTABOUTMODULEDIALOG_H
+#pragma once
 
 #include <QDialog>
 
+#include <QObject>
+#include <QString>
+#include <Qt>
+
 
 class CSwordModuleInfo;
 class QDialogButtonBox;
 class QTextEdit;
+class QWidget;
 
 /**
     Dialog to show the information about a module.
@@ -27,22 +31,20 @@ class BTAboutModuleDialog: public QDialog {
 
         Q_OBJECT
 
-    public: /* Methods: */
+    public: // methods:
 
         BTAboutModuleDialog(const CSwordModuleInfo *moduleInfo,
                             QWidget *parent = nullptr,
                             Qt::WindowFlags flags = Qt::WindowFlags());
 
-    protected: /* Methods: */
+    protected: // methods:
 
         void retranslateUi();
 
-    private: /* Fields: */
+    private: // fields:
 
         const CSwordModuleInfo *m_moduleInfo;
         QTextEdit        *m_textEdit;
         QDialogButtonBox *m_buttons;
 
 }; /* class BTAboutModuleDialog */
-
-#endif
