@@ -2,45 +2,48 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFGROUPINGMENU_H
-#define BTBOOKSHELFGROUPINGMENU_H
+#pragma once
 
 #include <QMenu>
 
+#include <QObject>
+#include <QString>
 #include "../backend/bookshelfmodel/btbookshelftreemodel.h"
 
 
 class QAction;
 class QActionGroup;
+class QWidget;
 
 class BtBookshelfGroupingMenu: public QMenu {
     Q_OBJECT
     public:
-        explicit inline BtBookshelfGroupingMenu(QWidget *parent = nullptr)
+        explicit BtBookshelfGroupingMenu(QWidget * parent = nullptr)
             : QMenu(parent) { initMenu(true); }
 
-        explicit inline BtBookshelfGroupingMenu(bool showNoGrouping,
-                                                QWidget *parent = nullptr)
+        explicit BtBookshelfGroupingMenu(bool showNoGrouping,
+                                         QWidget * parent = nullptr)
         : QMenu(parent) { initMenu(showNoGrouping); }
 
-    signals:
+    public Q_SLOTS:
+
+        void setGrouping(BtBookshelfTreeModel::Grouping const & grouping);
+
+    Q_SIGNALS:
         void signalGroupingOrderChanged(const BtBookshelfTreeModel::Grouping &);
 
     private:
         void initMenu(bool showNoGrouping);
         void retranslateUi();
 
-    private slots:
-        void slotGroupingActionTriggered(QAction *action);
-
     private:
         QActionGroup *m_groupingActionGroup;
         QAction *m_groupingCatLangAction;
@@ -49,5 +52,3 @@ class BtBookshelfGroupingMenu: public QMenu {
         QAction *m_groupingLangAction;
         QAction *m_groupingNoneAction;
 };
-
-#endif // BTBOOKSHELFGROUPINGMENU_H
