@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,10 +12,16 @@
 
 #include "btbookshelfview.h"
 
-#include <QApplication>
+#include <QAbstractItemModel>
+#include <QKeyEvent>
+#include <QModelIndex>
 #include <QMouseEvent>
-#include "../backend/bookshelfmodel/btbookshelftreemodel.h"
-#include "../backend/drivers/cswordmoduleinfo.h"
+#include <QPoint>
+#include <QRect>
+#include <QVariant>
+#include <QWidget>
+#include <Qt>
+#include "../backend/bookshelfmodel/btbookshelfmodel.h"
 #include "../util/btconnect.h"
 
 
@@ -32,10 +38,14 @@ BtBookshelfView::BtBookshelfView(QWidget *parent)
     */
     // setRootIsDecorated(false);
 
-    BT_CONNECT(this, SIGNAL(activated(QModelIndex)),
-               this, SLOT(slotItemActivated(QModelIndex)));
-    BT_CONNECT(this, SIGNAL(entered(QModelIndex)),
-               this, SLOT(slotItemHovered(QModelIndex)));
+    BT_CONNECT(this, &BtBookshelfView::activated,
+               [this](QModelIndex const & index) {
+                   if (auto * const module = getModule(index))
+                       Q_EMIT moduleActivated(module);
+               });
+    BT_CONNECT(this, &BtBookshelfView::entered,
+               [this](QModelIndex const & index)
+               { Q_EMIT moduleHovered(getModule(index)); });
 }
 
 CSwordModuleInfo * BtBookshelfView::getModule(const QModelIndex & index) const {
@@ -53,10 +63,10 @@ void BtBookshelfView::keyPressEvent(QKeyEvent *event) {
                 QRect itemRect(visualRect(currentIndex()));
                 QPoint p(viewport()->mapToGlobal(itemRect.bottomLeft()));
                 if (i == nullptr) {
-                    emit contextMenuActivated(p);
+                    Q_EMIT contextMenuActivated(p);
                 }
                 else {
-                    emit moduleContextMenuActivated(i, p);
+                    Q_EMIT moduleContextMenuActivated(i, p);
                 }
             }
             event->accept();
@@ -66,7 +76,7 @@ void BtBookshelfView::keyPressEvent(QKeyEvent *event) {
             QModelIndex i(currentIndex());
             CSwordModuleInfo *m(getModule(i));
             if (m != nullptr) {
-                emit moduleActivated(m);
+                Q_EMIT moduleActivated(m);
             }
             else {
                 setExpanded(i, !isExpanded(i));
@@ -88,10 +98,10 @@ void BtBookshelfView::mousePressEvent(QMouseEvent *event) {
         }
         CSwordModuleInfo *i(getModule(clickedItemIndex));
         if (i == nullptr) {
-            emit contextMenuActivated(mapToGlobal(event->pos()));
+            Q_EMIT contextMenuActivated(mapToGlobal(event->pos()));
         }
         else {
-            emit moduleContextMenuActivated(i, mapToGlobal(event->pos()));
+            Q_EMIT moduleContextMenuActivated(i, mapToGlobal(event->pos()));
         }
         event->accept();
     }
@@ -99,14 +109,3 @@ void BtBookshelfView::mousePressEvent(QMouseEvent *event) {
         QTreeView::mousePressEvent(event);
     }
 }
-
-void BtBookshelfView::slotItemActivated(const QModelIndex &index) {
-    CSwordModuleInfo *i(getModule(index));
-    if (i != nullptr) {
-        emit moduleActivated(i);
-    }
-}
-
-void BtBookshelfView::slotItemHovered(const QModelIndex &index) {
-    emit moduleHovered(getModule(index));
-}
