@@ -2,20 +2,23 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFWIDGET_H
-#define BTBOOKSHELFWIDGET_H
+#pragma once
 
 #include <QWidget>
 
-#include "../backend/bookshelfmodel/btbookshelftreemodel.h"
+#include <memory>
+#include <QObject>
+#include <QString>
+#include <QStringList>
+#include <Qt>
 
 
 class BtBookshelfFilterModel;
@@ -25,10 +28,12 @@ class BtBookshelfView;
 class QAbstractItemModel;
 class QAction;
 class QActionGroup;
+class QEvent;
 class QHBoxLayout;
 class QLabel;
 class QLineEdit;
 class QMenu;
+class QModelIndex;
 class QToolButton;
 
 class BtBookshelfWidget: public QWidget {
@@ -36,37 +41,40 @@ class BtBookshelfWidget: public QWidget {
     public:
         explicit BtBookshelfWidget(QWidget *parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());
 
-        void setSourceModel(QAbstractItemModel *model);
+        void setSourceModel(std::shared_ptr<QAbstractItemModel> model);
 
         // Getters for models:
-        inline BtBookshelfTreeModel *treeModel() const { return m_treeModel; }
-        inline BtBookshelfFilterModel *postFilterModel() const { return m_postFilterModel; }
+        BtBookshelfTreeModel * treeModel() const { return m_treeModel; }
+        BtBookshelfFilterModel * postFilterModel() const
+        { return m_postFilterModel; }
 
         // Setters for models:
         void setTreeModel(BtBookshelfTreeModel *model);
 
         // Getters for widgets:
-        inline QWidget *leftCornerWidget() const { return m_leftCornerWidget; }
-        inline QLabel *nameFilterLabel() const { return m_nameFilterLabel; }
-        inline QLineEdit *nameFilterEdit() const { return m_nameFilterEdit; }
-        inline QToolButton *groupingButton() const { return m_groupingButton; }
-        inline QToolButton *showHideButton() const { return m_showHideButton; }
-        inline QWidget *rightCornerWidget() const { return m_rightCornerWidget; }
-        inline BtBookshelfView *treeView() const { return m_treeView; }
-        inline BtBookshelfGroupingMenu *groupingMenu() const { return m_groupingMenu; }
-        inline QMenu *contextMenu() const { return m_contextMenu; }
-        inline QMenu *itemContextMenu() const { return m_itemContextMenu; }
+        QWidget * leftCornerWidget() const { return m_leftCornerWidget; }
+        QLabel * nameFilterLabel() const { return m_nameFilterLabel; }
+        QLineEdit * nameFilterEdit() const { return m_nameFilterEdit; }
+        QToolButton * groupingButton() const { return m_groupingButton; }
+        QToolButton * showHideButton() const { return m_showHideButton; }
+        QWidget * rightCornerWidget() const { return m_rightCornerWidget; }
+        BtBookshelfView * treeView() const { return m_treeView; }
+        BtBookshelfGroupingMenu * groupingMenu() const
+        { return m_groupingMenu; }
+        QMenu * contextMenu() const { return m_contextMenu; }
+        QMenu * itemContextMenu() const { return m_itemContextMenu; }
 
         // Setters for widgets:
         void setLeftCornerWidget(QWidget *w);
         void setRightCornerWidget(QWidget *w);
 
         // Getters for actions:
-        inline QAction *showHideAction() const { return m_showHideAction; }
+        QAction * showHideAction() const { return m_showHideAction; }
 
         // Setters for context menus:
-        inline void setContextMenu(QMenu *newMenu) { m_contextMenu = newMenu; }
-        inline void setItemContextMenu(QMenu *newMenu) { m_itemContextMenu = newMenu; }
+        void setContextMenu(QMenu * newMenu) { m_contextMenu = newMenu; }
+        void setItemContextMenu(QMenu * newMenu)
+        { m_itemContextMenu = newMenu; }
 
         bool eventFilter(QObject *object, QEvent *event) override;
 
@@ -81,14 +89,9 @@ class BtBookshelfWidget: public QWidget {
         void restoreExpanded(const QModelIndex& index, const QStringList& nodeList);
         void retranslateUi();
 
-    protected slots:
-        void slotGroupingActionTriggered(const BtBookshelfTreeModel::Grouping &grouping);
-        void slotShowContextMenu(const QPoint &pos);
-        void slotShowItemContextMenu(CSwordModuleInfo *module, const QPoint &pos);
-
     private:
         // Models:
-        QAbstractItemModel     *m_sourceModel;
+        std::shared_ptr<QAbstractItemModel> m_sourceModel;
         BtBookshelfTreeModel   *m_treeModel;
         BtBookshelfFilterModel *m_postFilterModel;
 
@@ -116,5 +119,3 @@ class BtBookshelfWidget: public QWidget {
         QAction *m_itemUnlockAction;
         QAction *m_itemAboutAction;
 };
-
-#endif // BTBOOKSHELFWIDGET_H
