@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,9 +12,16 @@
 
 #include "btmenuview.h"
 
+#include <QAbstractItemModel>
+#include <QAction>
 #include <QActionGroup>
 #include <QCoreApplication>
 #include <QEvent>
+#include <QIcon>
+#include <QModelIndex>
+#include <QPersistentModelIndex>
+#include <QVariant>
+#include <Qt>
 #include "../util/btassert.h"
 #include "../util/btconnect.h"
 
@@ -93,27 +100,27 @@ QAction *BtMenuView::newAction(QMenu *parentMenu, const QModelIndex &itemIndex)
     QAction *childAction = new QAction(parentMenu);
 
     // Set text:
-    if (displayData.canConvert(QVariant::String)) {
+    if (displayData.canConvert<QString>()) {
         childAction->setText(displayData.toString());
     }
 
     // Set icon:
-    if (iconData.canConvert(QVariant::Icon)) {
+    if (iconData.canConvert<QIcon>()) {
         childAction->setIcon(iconData.value<QIcon>());
     }
 
     // Set tooltip:
-    if (toolTipData.canConvert(QVariant::String)) {
+    if (toolTipData.canConvert<QString>()) {
         childAction->setToolTip(toolTipData.toString());
     }
 
     // Set status tip:
-    if (statusTipData.canConvert(QVariant::String)) {
+    if (statusTipData.canConvert<QString>()) {
         childAction->setStatusTip(statusTipData.toString());
     }
 
     // Set whatsthis:
-    if (whatsThisData.canConvert(QVariant::String)) {
+    if (whatsThisData.canConvert<QString>()) {
         childAction->setWhatsThis(whatsThisData.toString());
     }
 
@@ -143,27 +150,27 @@ QMenu *BtMenuView::newMenu(QMenu *parentMenu, const QModelIndex &itemIndex) {
     QMenu *childMenu = new QMenu(parentMenu);
 
     // Set text:
-    if (displayData.canConvert(QVariant::String)) {
+    if (displayData.canConvert<QString>()) {
         childMenu->setTitle(displayData.toString());
     }
 
     // Set icon:
-    if (iconData.canConvert(QVariant::Icon)) {
+    if (iconData.canConvert<QIcon>()) {
         childMenu->setIcon(iconData.value<QIcon>());
     }
 
     // Set tooltip:
-    if (toolTipData.canConvert(QVariant::String)) {
+    if (toolTipData.canConvert<QString>()) {
         childMenu->setToolTip(toolTipData.toString());
     }
 
     // Set status tip:
-    if (statusTipData.canConvert(QVariant::String)) {
+    if (statusTipData.canConvert<QString>()) {
         childMenu->setStatusTip(statusTipData.toString());
     }
 
     // Set whatsthis:
-    if (whatsThisData.canConvert(QVariant::String)) {
+    if (whatsThisData.canConvert<QString>()) {
         childMenu->setWhatsThis(whatsThisData.toString());
     }
 
