@@ -2,29 +2,26 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTPRINTER_H
-#define BTPRINTER_H
+#pragma once
 
 #include <QObject>
 #include "../backend/rendering/cdisplayrendering.h"
 
-#include "../backend/managers/cswordbackend.h"
-
 
 /** \brief Manages the print item queue and printing. */
 class BtPrinter final: public QObject, public Rendering::CDisplayRendering {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
     BtPrinter(DisplayOptions const & displayOptions,
               FilterOptions const & filterOptions,
@@ -32,15 +29,14 @@ public: /* Methods: */
 
     void printKeyTree(KeyTree const &);
 
-private: /* Methods: */
+private: // methods:
 
     QString entryLink(KeyTreeItem const & item,
-                      CSwordModuleInfo const * module) override;
+                      CSwordModuleInfo const & module) const override;
 
     QString renderEntry(KeyTreeItem const & item,
-                        CSwordKey * const key = nullptr) override;
-    QString finishText(QString const & text, KeyTree const & tree) override;
+                        CSwordKey * const key = nullptr) const override;
+    QString finishText(QString const & text, KeyTree const & tree)
+            const override;
 
 };
-
-#endif /* BTPRINTER_H */
