@@ -2,23 +2,21 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CKEYCHOOSER_H
-#define CKEYCHOOSER_H
+#pragma once
 
 #include <QWidget>
 
 #include "../../backend/drivers/btmodulelist.h"
 
 
-class BTHistory;
 class CSwordKey;
 class QAction;
 
@@ -32,12 +30,7 @@ class CKeyChooser: public QWidget {
 
     Q_OBJECT
 
-public: /* Methods: */
-
-    /**
-      \returns the history object of this keychooser.
-    */
-    inline BTHistory * history() const { return m_history; }
+public: // methods:
 
     /**
     * Creates a proper Instance, either
@@ -48,24 +41,15 @@ public: /* Methods: */
     * @param parent the parent of the widget to create
     */
     static CKeyChooser * createInstance(const BtConstModuleList & modules,
-                                        BTHistory * history,
                                         CSwordKey * key,
                                         QWidget * parent);
 
-public slots:
-
     /**
       Sets the CKey
       \param key the key which the widget should be set to.
     */
     virtual void setKey(CSwordKey * key) = 0;
 
-    /**
-      Updates the CKey.
-      \param key the key which the widget should be set to.
-    */
-    virtual void updateKey(CSwordKey * key) = 0;
-
     /**
       \returns the current CKey.
     */
@@ -82,32 +66,25 @@ public slots:
     */
     virtual void refreshContent() = 0;
 
-signals:
+public Q_SLOTS:
+
+    /**
+      Updates the CKey.
+      \param key the key which the widget should be set to.
+    */
+    virtual void updateKey(CSwordKey * key) = 0;
+
+    void handleHistoryMoved(QString const & newKey);
+
+Q_SIGNALS:
 
     /**
     * is emitted if the @ref CKey was changed by the user
     */
     void keyChanged(CSwordKey * newKey);
 
-protected: /* Methods: */
+protected: // methods:
 
-    CKeyChooser(const BtConstModuleList & info,
-                BTHistory * history,
-                QWidget * parent = nullptr);
-
-    /**
-      Resets the appropriate font to for the modules.
-    */
-    virtual void adjustFont() = 0;
-
-protected slots:
-
-    virtual void setKey(const QString & newKey) = 0;
-
-private: /* Fields: */
-
-    BTHistory * const m_history;
+    CKeyChooser(QWidget * parent = nullptr);
 
 };
-
-#endif
