@@ -2,31 +2,26 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef SEARCHCSEARCHANALYSISVIEW_H
-#define SEARCHCSEARCHANALYSISVIEW_H
+#pragma once
 
 #include <QGraphicsView>
 
-#include <QSize>
-
 
 class QResizeEvent;
+class QWidget;
 
 namespace Search {
 
 class CSearchAnalysisScene;
 
-/**
-    @author The BibleTime team <info@bibletime.info>
-*/
 class CSearchAnalysisView : public QGraphicsView {
     public:
         CSearchAnalysisView(CSearchAnalysisScene* scene, QWidget* parent);
@@ -38,5 +33,3 @@ class CSearchAnalysisView : public QGraphicsView {
 };
 
 }
-
-#endif
