@@ -2,22 +2,26 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTTABDIALOG_H
-#define BTTABDIALOG_H
+#pragma once
 
 #include <QDialog>
 
+#include <QObject>
+#include <QString>
+#include <Qt>
+
+
 class QDialogButtonBox;
-class QUrl;
 class QTextBrowser;
+class QWidget;
 
 namespace Search {
 
@@ -29,14 +33,9 @@ class BtSearchSyntaxHelpDialog: public QDialog {
     protected:
         void retranslateUi();
 
-    protected slots:
-        void linkClicked(const QUrl &url);
-
     private:
         QTextBrowser  *m_textBrowser;
         QDialogButtonBox *m_buttons;
 };
 
 } // namespace Search
-
-#endif
