@@ -2,28 +2,30 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CRANGECHOOSERDIALOG_H
-#define CRANGECHOOSERDIALOG_H
+#pragma once
 
 #include <QDialog>
 
 #include <QListWidgetItem>
+#include <QObject>
+#include <QString>
+#include <QStringList>
 
 
 class QDialogButtonBox;
 class QLabel;
 class QLineEdit;
-class QListWidget;
 class QPushButton;
 class QTextEdit;
+class QWidget;
 
 namespace Search {
 
@@ -32,36 +34,36 @@ class CRangeChooserDialog: public QDialog {
 
         Q_OBJECT
 
-private: /* Types: */
+private: // types:
 
     class RangeItem: public QListWidgetItem {
 
     public:
 
-        inline RangeItem(const QString &caption,
-                         const QString &range = QString(),
-                         QListWidget * parent = nullptr)
+        RangeItem(QString const & caption,
+                  QString const & range = QString(),
+                  QListWidget * parent = nullptr)
             : QListWidgetItem(caption, parent)
             , m_range(range) {}
 
-        inline const QString caption() const { return text(); }
-        inline void setCaption(const QString &caption) { setText(caption); }
-        inline const QString &range() const { return m_range; }
-        inline void setRange(const QString &range) { m_range = range; }
+        QString caption() const { return text(); }
+        void setCaption(QString const & caption) { setText(caption); }
+        QString const & range() const { return m_range; }
+        void setRange(QString const & range) { m_range = range; }
 
-    private: /* Fields: */
+    private: // fields:
 
         QString m_range;
 
     }; /* class RangeItem */
 
-public: /* Methods: */
+public: // methods:
 
     CRangeChooserDialog(const QStringList& rangeScopeModule, QWidget *parentDialog = nullptr);
 
     void accept() override;
 
-private: /* Methods: */
+private: // methods:
 
     /**
       Initializes widgets.
@@ -87,34 +89,7 @@ private: /* Methods: */
     */
     void resetEditControls();
 
-private slots:
-
-    /**
-      Adds a new range to the list.
-    */
-    void addNewRange();
-
-    /**
-      Handles changes in m_rangeList.
-    */
-    void selectedRangeChanged(QListWidgetItem * current,
-                              QListWidgetItem * previous);
-
-    /**
-      Parses the entered text and prints out the result in the list box below
-      the edit area.
-    */
-    void updateResultList();
-
-    /**
-      Deletes the selected range.
-    */
-    void deleteCurrentRange();
-
-    /**
-      Restores the default ranges.
-    */
-    void restoreDefaults();
+private Q_SLOTS:
 
     /**
       Called when m_nameEdit changes.
@@ -145,5 +120,3 @@ private:
 }; /* class CRangeChooserDialog */
 
 } /* namespace Search */
-
-#endif
