@@ -2,22 +2,24 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BT_SHORTCUTS_EDITOR_H
-#define BT_SHORTCUTS_EDITOR_H
+#pragma once
 
 #include <QWidget>
 
+#include <QKeySequence>
+#include <QObject>
+#include <QString>
+
 
 class BtActionCollection;
-class BtShortcutsEditorItem;
 class BtShortcutsDialog;
 class QGroupBox;
 class QLabel;
@@ -35,23 +37,24 @@ class BtShortcutsEditor : public QWidget {
         void commitChanges();
 
         // clears any shortcut keys in the table matching the specified keys
-        void clearConflictWithKeys(const QString& keys);
+        void clearConflictWithKeys(QKeySequence const & keys);
 
         // finds any shortcut keys in the table matching the specified keys - returns the Action Name for it.
-        QString findConflictWithKeys(const QString& keys);
+        QString findConflictWithKeys(QKeySequence const & keys) const;
 
         // used by application to complete the keyChangeRequest signal
         // stores "keys" into the custom shortcuts dialog field
-        void changeShortcutInDialog(const QString& keys);
+        void changeShortcutInDialog(QKeySequence const & keys);
 
-    signals:
-        // make a keyChangeRequest back to the application
-        void keyChangeRequest(BtShortcutsEditor*, const QString& keys);
+    Q_SIGNALS:
 
-    private slots:
+        void keyChangeRequest(QString const & actionName,
+                              QKeySequence const & keys);
+
+    private Q_SLOTS:
 
         // called when a different action name row is selected
-        void changeRow(int row, int column);
+        void slotSelectionChanged();
 
         // called when the none radio button is clicked
         void noneButtonClicked(bool checked);
@@ -62,14 +65,8 @@ class BtShortcutsEditor : public QWidget {
         // called when the custom radio button is clicked
         void customButtonClicked(bool checked);
 
-        // makes the keyChangeRequest
-        void makeKeyChangeRequest(const QString& keys);
-
     private:
 
-        // get the shortcut editor item from the zeroth column of the table
-        BtShortcutsEditorItem* getShortcutsEditor(int row);
-
         BtShortcutsDialog* m_dlg;
         QTableWidget* m_table;
         QGroupBox * m_shortcutChooser;
@@ -80,6 +77,3 @@ class BtShortcutsEditor : public QWidget {
         QLabel* m_defaultLabelValue;
         int m_currentRow;
 };
-
-#endif
-
