@@ -2,21 +2,22 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CRESMGR_H
-#define CRESMGR_H
+#pragma once
 
 #include <QKeySequence>
-#include <QString>
 #include "bticons.h"
 
+
+class QIcon;
+
 #define BT_GETICON2(fname,name) \
     inline QIcon const & fname() { return BtIcons::instance().icon_ ## name; }
 #define BT_GETICON(name) BT_GETICON2(icon,name)
@@ -73,124 +74,86 @@ namespace cults { BT_GETICON(questionable) }
 
 namespace mainMenu { // Main menu
 
+namespace file { // Main menu->File
+namespace quit { BT_GETICON(exit) }
+}
+
 namespace view { // Main menu->View
+namespace showFullscreen {
+BT_GETICON(window_fullscreen)
+}
 namespace showBookshelf { BT_GETICON(books) }
 namespace showBookmarks { BT_GETICON(bookmark) }
 namespace showMag { BT_GETICON(document_magnifier) }
 namespace showMainIndex {
 BT_GETICON(view_index)
-extern const QKeySequence accel;
-extern const char* actionName;
 } /* namespace showMainIndex { */
 namespace showInfoDisplay {
 BT_GETICON(view_mag)
-extern const QKeySequence accel;
-extern const char* actionName;
 } /* namespace showInfoDisplay { */
 } /* namespace view { */
 
 namespace mainIndex { //configuration for the main index and the view->search menu
 namespace search {
 BT_GETICON(find)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace searchdefaultbible {
 BT_GETICON(find)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 }
 
 namespace window { //Main menu->Window
-namespace quit { BT_GETICON(exit) }
 namespace loadProfile {
 BT_GETICON(view_profile)
-extern const char* actionName;
 }
 namespace saveProfile {
 BT_GETICON(view_profile)
-extern const char* actionName;
 }
 namespace saveToNewProfile {
 BT_GETICON(view_profile)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace deleteProfile {
 BT_GETICON(view_profile)
-extern const char* actionName;
-}
-namespace showFullscreen {
-BT_GETICON(window_fullscreen)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace arrangementMode {
 BT_GETICON(cascade_auto)
-extern const QKeySequence accel;
-extern const char* actionName;
 
 namespace manual {
 BT_GETICON(manual)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace autoTileHorizontal {
 BT_GETICON(tile_horiz_auto)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace autoTileVertical {
 BT_GETICON(tile_vert_auto)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace autoTile {
-BT_GETICON(tile_auto);
-extern const QKeySequence accel;
-extern const char* actionName;
+BT_GETICON(tile_auto)
 }
 namespace autoTabbed {
 BT_GETICON(tabbed)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace autoCascade {
 BT_GETICON(cascade_auto)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 }
 namespace tileHorizontal {
 BT_GETICON(tile_horiz)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace tileVertical {
 BT_GETICON(tile_vert)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace tile {
 BT_GETICON(tile)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace cascade {
 BT_GETICON(cascade)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace close {
 BT_GETICON(fileclose)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace closeAll {
 BT_GETICON(fileclose)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 }
 
@@ -198,26 +161,18 @@ namespace settings { //Main menu->Settings
 namespace configureDialog { BT_GETICON(configure) }
 namespace swordSetupDialog {
 BT_GETICON(swordconfig)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 }
 
 namespace help { //Main menu->Help
 namespace handbook {
 BT_GETICON(contents2)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace bibleStudyHowTo {
 BT_GETICON(contents2)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace tipOfTheDay {
 BT_GETICON(light_bulb)
-extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace aboutBibleTime { BT_GETICON(bibletime) }
 }
@@ -262,23 +217,23 @@ BT_GETICON2(icon_replaceModule, checkbox)
 namespace search {
 BT_GETICON(find)
 extern const QKeySequence accel;
-extern const char* actionName;
+extern QString const actionName;
 }
 
 namespace backInHistory {
 BT_GETICON(back)
 extern const QKeySequence accel;
-extern const char* actionName;
+extern QString const actionName;
 }
 namespace forwardInHistory {
 BT_GETICON(forward)
 extern const QKeySequence accel;
-extern const char* actionName;
+extern QString const actionName;
 }
 
 namespace findStrongs {
 extern const QKeySequence accel;
-extern const char* actionName;
+extern QString const actionName;
 }
 }
 
@@ -312,7 +267,7 @@ namespace commentaryWindow {
 namespace syncWindow {
 BT_GETICON(sync)
 extern const QKeySequence accel;
-extern const char* actionName;
+extern QString const actionName;
 }
 
 }
@@ -324,67 +279,41 @@ extern const QKeySequence accel;
 namespace previousEntry {
 extern const QKeySequence accel;
 }
-namespace copyMenu { BT_GETICON(edit_copy) }
-namespace saveMenu { BT_GETICON(file_save) }
-namespace printMenu { BT_GETICON(print) }
 }
 
 namespace writeWindow {
-namespace saveText {
-BT_GETICON(file_save)
-extern const QKeySequence accel;
-extern const char* actionName;
-}
-namespace restoreText {
-BT_GETICON(import)
-extern const QKeySequence accel;
-extern const char* actionName;
-}
-namespace deleteEntry {
-BT_GETICON(delete)
-extern const QKeySequence accel;
-extern const char* actionName;
-}
 
 //formatting buttons
 namespace boldText {
 BT_GETICON(text_bold)
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace italicText {
 BT_GETICON(text_italic)
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace underlinedText {
 BT_GETICON(text_under)
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 
 namespace alignLeft {
 BT_GETICON(text_leftalign)
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace alignCenter {
 BT_GETICON(text_center)
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace alignRight {
 BT_GETICON(text_rightalign)
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace fontFamily {
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace fontSize {
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 }
 }
@@ -402,7 +331,6 @@ namespace showHide { BT_GETICON(layer_visible_on) }
 namespace search {
 BT_GETICON(find)
 extern const QKeySequence accel;
-extern const char* actionName;
 }
 namespace newFolder { BT_GETICON(folder_add) }
 namespace changeFolder { BT_GETICON(folder) }
@@ -451,5 +379,3 @@ BT_GETICON2(icon_remove, remove)
 
 #undef BT_GETICON
 #undef BT_GETICON2
-
-#endif
